.. siiRL documentation master file, created by
   sphinx-quickstart on Wed Jul  9 15:26:45 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

siiRL documentation
===================

.. toctree::
   :maxdepth: 2
   :caption: Quickstart

   start/install
   start/quickstart

.. toctree::
   :maxdepth: 2
   :caption: Programming guide

   programming_guide/siirl_architecture_guide
   programming_guide/code_structure
   programming_guide/siiRL_code_explained
   programming_guide/srpo_code_explained

.. toctree::
   :maxdepth: 1
   :caption: Data Preparation

   preparation/prepare_data
   preparation/reward_function

.. toctree::
   :maxdepth: 2
   :caption: User Define Interface

   user_interface/filter_interface
   user_interface/reward_interface
   user_interface/pipeline_interface
   user_interface/metrics_interface

.. toctree::
   :maxdepth: 2
   :caption: Configurations

   examples/config

.. toctree::
   :maxdepth: 1
   :caption: Example

   examples/deepscaler_example
   examples/mm_eureka_example
   examples/cpgd_example
   examples/megatron_backend_example
   examples/embodied_srpo_example

.. toctree::
   :maxdepth: 1
   :caption: Hardware Support

   hardware_tutorial/ascend_quickstart
   hardware_tutorial/ascend_profiling_en
   hardware_tutorial/metax_quickstart
